devindex: Calculate development index

Description Usage Arguments Details

Description

Calculate development index

Usage

1

Arguments

formula

Index variables

data

Dataset

penalize

Penalize composite index.

wts

Indicator weights.

aggregate

Method of aggregation of indicator values.

Details

By default, function will calculate composite index penalized using Mazziotta-Pareto method. Setting penalize = FALSE will calculate composite index as a simple non-weighted mean of indicator values.

To use indicator weights specify wts as a named list.

Method of aggregation of indicator values is set via aggregate argument. Default is mean, but it can be a name of any function (typical alternative is sum).

By setting both penalize = TRUE and wts it is possible to use weighted indicators with penalization.


dataspekt/crodi documentation built on May 30, 2019, 4:06 a.m.